@@ -17,7 +17,7 @@ sub _carp {
     return warn @_, " at $file line $line\n";
 }
 
-our $VERSION = '1.302049';
+our $VERSION = '1.302067';
 
 use Test::Builder::Module;
 our @ISA    = qw(Test::Builder::Module);
@@ -125,6 +125,8 @@ the end.
 
   done_testing( $number_of_tests_run );
 
+B<NOTE> C<done_testing()> should never be called in an C<END { ... }> block.
+
 Sometimes you really don't know how many tests were run, or it's too
 difficult to calculate.  In which case you can leave off
 $number_of_tests_run.
@@ -232,6 +234,10 @@ conclusion.
 
 This is safer than and replaces the "no_plan" plan.
 
+B<Note:> You must never put C<done_testing()> inside an C<END { ... }> block.
+The plan is there to ensure your test does not exit before testing has
+completed. If you use an END block you completely bypass this protection.
+
 =back
 
 =cut
@@ -970,7 +976,10 @@ sub use_ok ($;@) {
     @imports = () unless @imports;
     my $tb = Test::More->builder;
 
-    my( $pack, $filename, $line ) = caller;
+    my %caller;
+    @caller{qw/pack file line sub args want eval req strict warn/} = caller(0);
+
+    my ($pack, $filename, $line, $warn) = @caller{qw/pack file line warn/};
     $filename =~ y/\n\r/_/; # so it doesn't run off the "#line $line $f" line
 
     my $code;
@@ -979,7 +988,7 @@ sub use_ok ($;@) {
         # for it to work with non-Exporter based modules.
         $code = <<USE;
 package $pack;
-
+BEGIN { \${^WARNING_BITS} = \$args[-1] if defined \$args[-1] }
 #line $line $filename
 use $module $imports[0];
 1;
@@ -988,14 +997,14 @@ USE
     else {
         $code = <<USE;
 package $pack;
-
+BEGIN { \${^WARNING_BITS} = \$args[-1] if defined \$args[-1] }
 #line $line $filename
 use $module \@{\$args[0]};
 1;
 USE
     }
 
-    my( $eval_result, $eval_error ) = _eval( $code, \@imports );
+    my ($eval_result, $eval_error) = _eval($code, \@imports, $warn);
     my $ok = $tb->ok( $eval_result, "use $module;" );
 
     unless($ok) {
@@ -1064,6 +1073,20 @@ improve in the future.
 L<Test::Differences> and L<Test::Deep> provide more in-depth functionality
 along these lines.
 
+B<NOTE> is_deeply() has limitations when it comes to comparing strings and
+refs:
+
+    my $path = path('.');
+    my $hash = {};
+    is_deeply( $path, "$path" ); # ok
+    is_deeply( $hash, "$hash" ); # fail
+
+This happens because is_deeply will unoverload all arguments unconditionally.
+It is probably best not to use is_deeply with overloading. For legacy reasons
+this is not likely to ever be fixed. If you would like a much better tool for
+this you should see L<Test2::Suite> Specifically L<Test2::Tools::Compare> has
+an C<is()> function that works like C<is_deeply> with many improvements.
+
 =cut
 
 our( @Data_Stack, %Refs_Seen );
@@ -1164,7 +1187,7 @@ sub _type {
 
     return '' if !ref $thing;
 
-    for my $type (qw(Regexp ARRAY HASH REF SCALAR GLOB CODE)) {
+    for my $type (qw(Regexp ARRAY HASH REF SCALAR GLOB CODE VSTRING)) {
         return $type if UNIVERSAL::isa( $thing, $type );
     }
 
@@ -1956,7 +1979,7 @@ the perl-qa gang.
 
 =head1 BUGS
 
-See F<http://rt.cpan.org> to report and view bugs.
+See F<https://github.com/Test-More/test-more/issues> to report and view bugs.
 
 
 =head1 SOURCE
