@@ -2,7 +2,12 @@ package Test2::API;
 use strict;
 use warnings;
 
-our $VERSION = '1.302049';
+BEGIN {
+    $ENV{TEST_ACTIVE} ||= 1;
+    $ENV{TEST2_ACTIVE} = 1;
+}
+
+our $VERSION = '1.302067';
 
 
 my $INST;
@@ -217,7 +222,7 @@ sub context {
         unless defined wantarray;
 
     my $stack   = $params{stack} || $STACK;
-    my $hub     = $params{hub}   || @$stack ? $stack->[-1] : $stack->top;
+    my $hub     = $params{hub}   || (@$stack ? $stack->[-1] : $stack->top);
     my $hid     = $hub->{hid};
     my $current = $CONTEXTS->{$hid};
 
@@ -389,11 +394,17 @@ sub intercept(&) {
     $ctx->stack->top; # Make sure there is a top hub before we begin.
     $ctx->stack->push($hub);
 
-    # Do not use 'try' cause it localizes __DIE__
-    my ($ok, $err);
-    {
+    my ($ok, $err) = (1, undef);
+    T2_SUBTEST_WRAPPER: {
+        # Do not use 'try' cause it localizes __DIE__
         $ok = eval { $code->(hub => $hub, context => $ctx->snapshot); 1 };
         $err = $@;
+
+        # They might have done 'BEGIN { skip_all => "whatever" }'
+        if (!$ok && $err =~ m/Label not found for "last T2_SUBTEST_WRAPPER"/ || (blessed($err) && $err->isa('Test2::Hub::Interceptor::Terminator'))) {
+            $ok  = 1;
+            $err = undef;
+        }
     }
 
     $hub->cull;
@@ -402,8 +413,7 @@ sub intercept(&) {
     my $trace = $ctx->trace;
     $ctx->release;
 
-    die $err unless $ok
-        || (blessed($err) && $err->isa('Test2::Hub::Interceptor::Terminator'));
+    die $err unless $ok;
 
     $hub->finalize($trace, 1)
         if $ok
@@ -442,6 +452,14 @@ sub run_subtest {
             $hub->format(undef) if $hide;
         }
     }
+    elsif (! $parent->format) {
+        # If our parent has no format that means we're in a buffered subtest
+        # and now we're trying to run a streaming subtest. There's really no
+        # way for that to work, so we need to force the use of a buffered
+        # subtest here as
+        # well. https://github.com/Test-More/test-more/issues/721
+        $buffered = 1;
+    }
 
     if ($inherit_trace) {
         my $orig = $code;
