@@ -2,11 +2,11 @@ package Test2::API::Context;
 use strict;
 use warnings;
 
-our $VERSION = '1.302049';
+our $VERSION = '1.302067';
 
 
 use Carp qw/confess croak longmess/;
-use Scalar::Util qw/weaken/;
+use Scalar::Util qw/weaken blessed/;
 use Test2::Util qw/get_tid try pkg_to_file get_tid/;
 
 use Test2::Util::Trace();
@@ -25,7 +25,7 @@ my %LOADED = (
 use Test2::Util::ExternalMeta qw/meta get_meta set_meta delete_meta/;
 use Test2::Util::HashBase qw{
     stack hub trace _on_release _depth _is_canon _is_spawn _aborted
-    errno eval_error child_error
+    errno eval_error child_error thrown
 };
 
 # Private, not package vars
@@ -66,9 +66,13 @@ sub DESTROY {
 
     # Do not show the warning if it looks like an exception has been thrown, or
     # if the context is not local to this process or thread.
-    if($self->{+EVAL_ERROR} eq $@ && $hub->is_local) {
-        my $frame = $self->{+_IS_SPAWN} || $self->{+TRACE}->frame;
-        warn <<"        EOT";
+    {
+        # Sometimes $@ is uninitialized, not a problem in this case so do not
+        # show the warning about using eq.
+        no warnings 'uninitialized';
+        if($self->{+EVAL_ERROR} eq $@ && $hub->is_local) {
+            my $frame = $self->{+_IS_SPAWN} || $self->{+TRACE}->frame;
+            warn <<"            EOT";
 A context appears to have been destroyed without first calling release().
 Based on \$@ it does not look like an exception was thrown (this is not always
 a reliable test)
@@ -84,7 +88,8 @@ release():
   Tool: $frame->[3]
 
 Cleaning up the CONTEXT stack...
-        EOT
+            EOT
+        }
     }
 
     return if $self->{+_IS_SPAWN};
@@ -109,6 +114,8 @@ Cleaning up the CONTEXT stack...
 sub release {
     my ($self) = @_;
 
+    ($!, $@, $?) = @$self{+ERRNO, +EVAL_ERROR, +CHILD_ERROR} and return if $self->{+THROWN};
+
     ($!, $@, $?) = @$self{+ERRNO, +EVAL_ERROR, +CHILD_ERROR} and return $self->{+_IS_SPAWN} = undef
         if $self->{+_IS_SPAWN};
 
@@ -184,6 +191,7 @@ sub done_testing {
 
 sub throw {
     my ($self, $msg) = @_;
+    $self->{+THROWN} = 1;
     ${$self->{+_ABORTED}}++ if $self->{+_ABORTED};
     $self->release if $self->{+_IS_CANON} || $self->{+_IS_SPAWN};
     $self->trace->throw($msg);
@@ -201,12 +209,13 @@ sub send_event {
 
     my $pkg = $LOADED{$event} || $self->_parse_event($event);
 
-    $self->{+HUB}->send(
-        $pkg->new(
-            trace => $self->{+TRACE}->snapshot,
-            %args,
-        )
+    my $e = $pkg->new(
+        trace => $self->{+TRACE}->snapshot,
+        %args,
     );
+
+    ${$self->{+_ABORTED}}++ if $self->{+_ABORTED} && defined $e->terminate;
+    $self->{+HUB}->send($e);
 }
 
 sub build_event {
@@ -242,7 +251,7 @@ sub ok {
 
     if ($on_fail && @$on_fail) {
         for my $of (@$on_fail) {
-            if (ref($of)) {
+            if (ref($of) eq 'CODE' || (blessed($of) && $of->can('render'))) {
                 $self->info($of, diagnostics => 1);
             }
             else {
@@ -317,13 +326,11 @@ sub diag {
 
 sub plan {
     my ($self, $max, $directive, $reason) = @_;
-    ${$self->{+_ABORTED}}++ if $self->{+_ABORTED} && $directive && $directive =~ m/^(SKIP|skip_all)$/;
     $self->send_event('Plan', max => $max, directive => $directive, reason => $reason);
 }
 
 sub bail {
     my ($self, $reason) = @_;
-    ${$self->{+_ABORTED}}++ if $self->{+_ABORTED};
     $self->send_event('Bail', reason => $reason);
 }
 
